@@ -5,7 +5,7 @@
 set -e
 set x
 #
-env seed=42 flam3-genome > random.flam3
+flam3-genome > random.flam3
 xmllint -noout random.flam3
 flam3-render < random.flam3
 pngcheck 00000.png
